SurferLayout

Struct SurferLayout 

pub struct SurferLayout {
Show 36 fields show_hierarchy: bool, show_menu: bool, show_toolbar: bool, show_ticks: bool, show_tooltip: bool, show_scope_tooltip: bool, show_overview: bool, show_statusbar: bool, show_variable_indices: bool, show_variable_direction: bool, show_default_timeline: bool, show_empty_scopes: bool, show_hierarchy_icons: bool, parameter_display_location: ParameterDisplayLocation, pub window_height: usize, pub window_width: usize, pub window_x_position: usize, pub window_y_position: usize, align_names_right: bool, hierarchy_style: HierarchyStyle, pub waveforms_text_size: f32, pub waveforms_line_height: f32, pub waveforms_gap: f32, pub waveforms_line_height_multiples: Vec<f32>, pub analog_waveform_multiplier: f32, pub transactions_line_height: f32, pub zoom_factors: Vec<f32>, default_zoom_factor: f32, focus_highlight: FocusHighlight, move_focus_on_inserted_marker: bool, fill_high_values: bool, draw_vector_unknowns_as_line: bool, trace_style: TraceStyle, transition_value: TransitionValue, toolbar: ToolbarLayout, pub enable_time_offset: bool,
}

Fields

show_hierarchy: bool

Flag to show/hide the hierarchy view

show_menu: bool

Flag to show/hide the menu

show_toolbar: bool

Flag to show/hide toolbar

show_ticks: bool

Flag to show/hide tick lines

show_tooltip: bool

Flag to show/hide tooltip for variables

show_scope_tooltip: bool

Flag to show/hide tooltip for scopes

show_overview: bool

Flag to show/hide the overview

show_statusbar: bool

Flag to show/hide the statusbar

show_variable_indices: bool

Flag to show/hide the indices of variables in the variable list

show_variable_direction: bool

Flag to show/hide the variable direction icon

show_default_timeline: bool

Flag to show/hide a default timeline

show_empty_scopes: bool

Flag to show/hide empty scopes

show_hierarchy_icons: bool

Flag to show/hide scope and variable type icons in the hierarchy

parameter_display_location: ParameterDisplayLocation

Where to show parameters in the hierarchy

window_height: usize

Initial window height

window_width: usize

Initial window width

window_x_position: usize

Initial window x-position

window_y_position: usize

Initial window y-position

align_names_right: bool

Align variable names right

hierarchy_style: HierarchyStyle

Set style of hierarchy

waveforms_text_size: f32

Text size in points for values in waves

waveforms_line_height: f32

Line height in points for waves

waveforms_gap: f32

Pixel gap between consecutive waveform traces

waveforms_line_height_multiples: Vec<f32>

Line height multiples for higher variables

analog_waveform_multiplier: f32

Default analog waveform multiplier

transactions_line_height: f32

Line height in points for transaction streams

zoom_factors: Vec<f32>

UI zoom factors

default_zoom_factor: f32

Default UI zoom factor

focus_highlight: FocusHighlight

How to highlight the focused waveform

move_focus_on_inserted_marker: bool

Move the focus to the newly inserted marker?

fill_high_values: bool

Fill high values in boolean waveforms

draw_vector_unknowns_as_line: bool

Draw unknown vector waveform values as a centered horizontal line

trace_style: TraceStyle

Trace style for vector waveforms

transition_value: TransitionValue

Value to display when cursor is on a transition

toolbar: ToolbarLayout

Toolbar-specific layout settings

enable_time_offset: bool

Enable time offset adjustment for waveforms which don’t start at 0. When enabled, the waveform canvas will be drawn from the first available time instead of from 0.

Implementations