pub struct SurferTheme {Show 41 fields
pub foreground: Color32,
pub border_color: Color32,
pub alt_text_color: Color32,
pub canvas_colors: ThemeColorTriple,
pub primary_ui_color: ThemeColorPair,
pub secondary_ui_color: ThemeColorPair,
pub selected_elements_colors: ThemeColorPair,
pub accent_info: ThemeColorPair,
pub accent_warn: ThemeColorPair,
pub accent_error: ThemeColorPair,
pub cursor: SurferLineStyle,
pub gesture: SurferLineStyle,
pub measure: SurferLineStyle,
pub clock_highlight_line: SurferLineStyle,
pub clock_highlight_cycle: Color32,
pub clock_rising_marker: bool,
pub variable_default: Color32,
pub variable_highimp: Color32,
pub variable_undef: Color32,
pub variable_dontcare: Color32,
pub variable_weak: Color32,
pub variable_parameter: Color32,
pub transaction_default: Color32,
pub relation_arrow: SurferRelationArrow,
pub variable_event: Color32,
pub waveform_opacity: f32,
pub wide_opacity: f32,
pub colors: HashMap<String, Color32>,
pub highlight_background: Color32,
pub linewidth: f32,
pub thick_linewidth: f32,
pub vector_transition_width: f32,
pub alt_frequency: usize,
pub viewport_separator: SurferLineStyle,
pub drag_hint_color: Color32,
pub drag_hint_width: f32,
pub drag_threshold: f32,
pub ticks: SurferTicks,
pub theme_names: Vec<String>,
pub scope_icons: ScopeIcons,
pub variable_icons: VariableIcons,
}Fields
foreground: Color32Color used for text across the UI
border_color: Color32Color of borders between UI elements
alt_text_color: Color32Color used for text across the markers
canvas_colors: ThemeColorTripleColors used for the background and text of the wave view
primary_ui_color: ThemeColorPairColors used for most UI elements not on the variable canvas
secondary_ui_color: ThemeColorPairColors used for the variable and value list, as well as secondary elements like text fields
selected_elements_colors: ThemeColorPairColor used for selected ui elements such as the currently selected hierarchy
accent_info: ThemeColorPairaccent_warn: ThemeColorPairaccent_error: ThemeColorPaircursor: SurferLineStyleLine style for cursor
gesture: SurferLineStyleLine style for mouse gesture lines
measure: SurferLineStyleLine style for measurement lines
clock_highlight_line: SurferLineStyleLine style for clock highlight lines
clock_highlight_cycle: Color32clock_rising_marker: boolDraw arrows on rising clock edges
variable_default: Color32Default variable color
variable_highimp: Color32Color used for high-impedance variables
variable_undef: Color32Color used for undefined variables
variable_dontcare: Color32Color used for don’t-care variables
variable_weak: Color32Color used for weak variables
variable_parameter: Color32Color used for constant variables (parameters)
transaction_default: Color32Default transaction color
relation_arrow: SurferRelationArrowvariable_event: Color32Color used for constant variables (parameters)
waveform_opacity: f32Opacity with which variable backgrounds are drawn. 0 is fully transparent and 1 is fully opaque.
wide_opacity: f32Opacity of variable backgrounds for wide signals (signals with more than one bit)
colors: HashMap<String, Color32>highlight_background: Color32linewidth: f32Variable line width
thick_linewidth: f32Variable line width for accented variables
vector_transition_width: f32Vector transition max width
alt_frequency: usizeNumber of lines using standard background before changing to alternate background and so on, set to zero to disable
viewport_separator: SurferLineStyleViewport separator line
drag_hint_color: Color32drag_hint_width: f32drag_threshold: f32ticks: SurferTicksTick information
theme_names: Vec<String>List of theme names
scope_icons: ScopeIconsIcons for scope types in the hierarchy view
variable_icons: VariableIconsIcons for variable types in the hierarchy view
Implementations
Sourceimpl SurferTheme
impl SurferTheme
pub fn get_color(&self, color: &str) -> Option<Color32>
pub fn get_best_text_color(&self, backgroundcolor: Color32) -> Color32
fn generate_defaults( theme_name: Option<&String>, ) -> (ConfigBuilder<DefaultState>, Vec<String>)
pub fn new(theme_name: Option<String>) -> Result<Self>