pub struct SurferLayout {Show 29 fields
show_hierarchy: bool,
show_menu: bool,
show_toolbar: bool,
show_ticks: bool,
show_tooltip: bool,
show_scope_tooltip: bool,
show_overview: bool,
show_statusbar: bool,
show_variable_indices: bool,
show_variable_direction: bool,
show_default_timeline: bool,
show_empty_scopes: bool,
show_hierarchy_icons: bool,
parameter_display_location: ParameterDisplayLocation,
pub window_height: usize,
pub window_width: usize,
align_names_right: bool,
hierarchy_style: HierarchyStyle,
pub waveforms_text_size: f32,
pub waveforms_line_height: f32,
pub waveforms_line_height_multiples: Vec<f32>,
pub transactions_line_height: f32,
pub zoom_factors: Vec<f32>,
pub default_zoom_factor: f32,
highlight_focused: bool,
move_focus_on_inserted_marker: bool,
fill_high_values: bool,
use_dinotrace_style: bool,
transition_value: TransitionValue,
}Fields
show_hierarchy: boolFlag to show/hide the hierarchy view
Flag to show/hide the menu
show_toolbar: boolFlag to show/hide toolbar
show_ticks: boolFlag to show/hide tick lines
show_tooltip: boolFlag to show/hide tooltip for variables
show_scope_tooltip: boolFlag to show/hide tooltip for scopes
show_overview: boolFlag to show/hide the overview
show_statusbar: boolFlag to show/hide the statusbar
show_variable_indices: boolFlag to show/hide the indices of variables in the variable list
show_variable_direction: boolFlag to show/hide the variable direction icon
show_default_timeline: boolFlag to show/hide a default timeline
show_empty_scopes: boolFlag to show/hide empty scopes
show_hierarchy_icons: boolFlag to show/hide scope and variable type icons in the hierarchy
parameter_display_location: ParameterDisplayLocationWhere to show parameters in the hierarchy
window_height: usizeInitial window height
window_width: usizeInitial window width
align_names_right: boolAlign variable names right
hierarchy_style: HierarchyStyleSet style of hierarchy
waveforms_text_size: f32Text size in points for values in waves
waveforms_line_height: f32Line height in points for waves
waveforms_line_height_multiples: Vec<f32>Line height multiples for higher variables
transactions_line_height: f32Line height in points for transaction streams
zoom_factors: Vec<f32>UI zoom factors
default_zoom_factor: f32Default UI zoom factor
highlight_focused: boolHighlight the waveform of the focused item?
move_focus_on_inserted_marker: boolMove the focus to the newly inserted marker?
fill_high_values: boolFill high values in boolean waveforms
use_dinotrace_style: boolDinotrace drawing style (thick upper line for all-ones, no upper line for all-zeros)
transition_value: TransitionValueValue to display when cursor is on a transition
Implementations
Sourceimpl SurferLayout
impl SurferLayout
pub fn show_hierarchy(&self) -> bool
pub fn show_ticks(&self) -> bool
pub fn show_tooltip(&self) -> bool
pub fn show_scope_tooltip(&self) -> bool
pub fn show_default_timeline(&self) -> bool
pub fn show_toolbar(&self) -> bool
pub fn show_overview(&self) -> bool
pub fn show_statusbar(&self) -> bool
pub fn align_names_right(&self) -> bool
pub fn show_variable_indices(&self) -> bool
pub fn show_variable_direction(&self) -> bool
pub fn default_zoom_factor(&self) -> f32
pub fn show_empty_scopes(&self) -> bool
pub fn show_hierarchy_icons(&self) -> bool
pub fn parameter_display_location(&self) -> ParameterDisplayLocation
pub fn highlight_focused(&self) -> bool
pub fn move_focus_on_inserted_marker(&self) -> bool
pub fn fill_high_values(&self) -> bool
pub fn hierarchy_style(&self) -> HierarchyStyle
pub fn use_dinotrace_style(&self) -> bool
pub fn transition_value(&self) -> TransitionValue